==> fiber-css-0.4.0.tgz: package/src/styleVariables.js <==

const one = 0.0625

const colors = {
  "color-red-500":            "#F44336",
  "color-red-700":            "#D32F2F",
  "color-pink-500":           "#E91E63",
  "color-pink-700":           "#C2185B",
  "color-purple-500":         "#9C27B0",
  "color-purple-700":         "#7B1FA2",
  "color-indigo-500":         "#3F51B5",
  "color-indigo-700":         "#303F9F",
  "color-blue-500":           "#2196F3",
  "color-blue-700":           "#1976D2",
  "color-light-blue-500":     "#03A9F4",
  "color-light-blue-700":     "#0288D1",
  "color-cyan-500":           "#00BCD4",
  "color-cyan-700":           "#0097A7",
  "color-teal-500":           "#009688",
  "color-teal-700":           "#00796B",
  "color-green-500":          "#4CAF50",
  "color-green-700":          "#388E3C",
  "color-light-green-500":    "#8BC34A",
  "color-light-green-700":    "#689F38",
  "color-lime-500":           "#CDDC39",
  "color-lime-700":           "#AFB42B",
  "color-yellow-500":         "#FFEB3B",
  "color-yellow-700":         "#FBC02D",
  "color-amber-500":          "#FFC107",
  "color-amber-700":          "#FFA000",
  "color-orange-500":         "#FF9800",
  "color-orange-700":         "#F57C00",
  "color-deep-orange-500":    "#FF5722",
  "color-deep-orange-700":    "#E64A19",
  "color-brown-500":          "#795548",
  "color-brown-700":          "#5D4037",
  "color-grey-100":           "#F5F5F5",
  "color-grey-200":           "#EEEEEE",
  "color-grey-300":           "#E0E0E0",
  "color-grey-400":           "#BDBDBD",
  "color-grey-500":           "#9E9E9E",
  "color-grey-600":           "#757575",
  "color-grey-700":           "#616161",
  "color-grey-800":           "#424242",
  "color-grey-900":           "#212121",
  "color-white":              "#FFFFFF",
  "color-black":              "#000000",
}

const coreVars = {
  "sans-serif":               "\"Roboto\", sans-serif",
  "one":                      `${one}rem`,
  "one-relative":             `${one}em`,
  "base-font-size":           "1rem",
  "base-unit":                "1rem",
  "base-space":               "1rem",
  "base-line-height":         1.5,
  "small-line-height":        1.2,
  "font-size-0":              `${13 * one}rem`,
  "font-size-1":              `${16 * one}rem`,
  "font-size-2":              `${20 * one}rem`,
  "font-size-3":              `${24 * one}rem`,
  "font-size-4":              `${32 * one}rem`,
  "font-size-5":              `${44 * one}rem`,
  "font-size-6":              `${56 * one}rem`,
  "text-color-base":          colors["color-grey-900"],
  "color-primary":            colors["color-pink-500"],
  "color-primary-contrast":   colors["color-white"],
  "color-secondary":          colors["color-grey-200"],
  "color-secondary-contrast": colors["text-color-base"],
  "text-select-bg":           colors["color-primary"],
  "text-select-color":        colors["color-white"],
  "shadow-light":             0.08,
  "shadow-medium":            0.12,
  "shadow-dark":              0.16,
}

const variables = Object.assign({}, colors, coreVars)

module.exports = variables

==> fiber-css-0.5.1.tgz: package/src/styleVariables.js <==

const one = 0.0625

const colors = {
  "color-red-500":            "#F44336",
  "color-red-700":            "#D32F2F",
  "color-pink-500":           "#E91E63",
  "color-pink-700":           "#C2185B",
  "color-purple-500":         "#9C27B0",
  "color-purple-700":         "#7B1FA2",
  "color-indigo-500":         "#3F51B5",
  "color-indigo-700":         "#303F9F",
  "color-blue-500":           "#2196F3",
  "color-blue-700":           "#1976D2",
  "color-light-blue-500":     "#03A9F4",
  "color-light-blue-700":     "#0288D1",
  "color-cyan-500":           "#00BCD4",
  "color-cyan-700":           "#0097A7",
  "color-teal-500":           "#009688",
  "color-teal-700":           "#00796B",
  "color-green-500":          "#4CAF50",
  "color-green-700":          "#388E3C",
  "color-light-green-500":    "#8BC34A",
  "color-light-green-700":    "#689F38",
  "color-lime-500":           "#CDDC39",
  "color-lime-700":           "#AFB42B",
  "color-yellow-500":         "#FFEB3B",
  "color-yellow-700":         "#FBC02D",
  "color-amber-500":          "#FFC107",
  "color-amber-700":          "#FFA000",
  "color-orange-500":         "#FF9800",
  "color-orange-700":         "#F57C00",
  "color-deep-orange-500":    "#FF5722",
  "color-deep-orange-700":    "#E64A19",
  "color-brown-500":          "#795548",
  "color-brown-700":          "#5D4037",
  "color-grey-100":           "#F5F5F5",
  "color-grey-200":           "#EEEEEE",
  "color-grey-300":           "#E0E0E0",
  "color-grey-400":           "#BDBDBD",
  "color-grey-500":           "#9E9E9E",
  "color-grey-600":           "#757575",
  "color-grey-700":           "#616161",
  "color-grey-800":           "#424242",
  "color-grey-900":           "#212121",
  "color-white":              "#FFFFFF",
  "color-black":              "#000000",
}

const coreVars = {
  "sans-serif":               "\"Roboto\", sans-serif",
  "one":                      `${one}rem`,
  "one-relative":             `${one}em`,
  "base-font-size":           "1rem",
  "base-unit":                "1rem",
  "base-space":               "1rem",
  "base-line-height":         1.5,
  "small-line-height":        1.2,
  "font-size-0":              `${13 * one}rem`,
  "font-size-1":              `${16 * one}rem`,
  "font-size-2":              `${20 * one}rem`,
  "font-size-3":              `${24 * one}rem`,
  "font-size-4":              `${32 * one}rem`,
  "font-size-5":              `${44 * one}rem`,
  "font-size-6":              `${56 * one}rem`,
  "text-color-base":          colors["color-grey-900"],
  "color-primary":            colors["color-pink-500"],
  "color-primary-contrast":   colors["color-white"],
  "color-secondary":          colors["color-grey-200"],
  "color-secondary-contrast": colors["text-color-base"],
  "text-select-bg":           colors["color-pink-500"],
  "text-select-color":        colors["color-white"],
  "shadow-light":             0.08,
  "shadow-medium":            0.12,
  "shadow-dark":              0.16,
}

const variables = Object.assign({}, colors, coreVars)

module.exports = variables
